testedit
Lib: colours_library

Lead dev: Eryk Malczyk

INSTALLATION

pip install colours_library


----------------------------

USAGE

python3

------------>

import colours_library

------------->

colours_library.produce('path_to_image', N(number of colours))

-----------------------------
OUTPUT

List of N colours sorted by frequency.
